CREATE OR REPLACE FORCE VIEW "SCHEMA"."DWH_X_RES_AVAIL_PER_FACTS_V" ("RESOURCE_KEY", "PERIOD_KEY", "AVAIL_HOURS", "SLICE_CREATED_DATE")
AS
  SELECT a.resource_key,
    a.period_key,
    NVL (a.slice, 0) avail_hours,
    a.created_date slice_created_date
  FROM
    (WITH slice_range AS
    (SELECT MIN(from_date) from_date,
      MAX(num_periods) row_count
    FROM prj_blb_slicerequests
    WHERE is_dwh_request = 1
    AND 1                =
      (SELECT fiscal_slices FROM dwh_settings
      )
    AND request_name = 'resource::pravailcurve::dwh_fiscal'
    ),
    fiscal_periods AS
    (SELECT d.period_key,
      d.period_start,
      d.row_key
    FROM
      (SELECT p.id period_key,
        p.start_date period_start,
        r.row_count,
        ROW_NUMBER() OVER (PARTITION BY p.entity_id ORDER BY p.start_date) AS row_key
      FROM biz_com_periods p,
        dwh_settings s,
        slice_range r
      WHERE p.entity_id  = s.entity_key
      AND p.period_type IN ('MONTHLY','13_PERIODS_PER_YEAR')
      AND p.start_date  >= r.from_date
      ) d
    WHERE d.row_key <= d.row_count
    ),
    cal_slice_keys AS
    (SELECT id request_key,
      CASE
        WHEN period = 1
        THEN 'WEEKLY'
        ELSE 'MONTHLY'
      END period_type
    FROM prj_blb_slicerequests
    WHERE is_dwh_request                            = 1
    AND (((SELECT monthly_slices FROM dwh_settings) = 1
    AND request_name                                = 'MONTHLYRESOURCEAVAILCURVE')
    OR ((SELECT weekly_slices FROM dwh_settings)    = 1
    AND request_name                                = 'WEEKLYRESOURCEAVAILCURVE'))
    ),
    fiscal_slice_key AS
    (SELECT id request_key,
      period period_type
    FROM prj_blb_slicerequests
    WHERE is_dwh_request                         = 1
    AND (SELECT fiscal_slices FROM dwh_settings) = 1
    AND request_name                             = 'resource::pravailcurve::dwh_fiscal'
    )
  SELECT s.prj_object_id resource_key,
    CASE
      WHEN sk.period_type = 'WEEKLY'
      THEN CAST(s.slice_date  - TO_DATE ('01/01/2000', 'MM/DD/YYYY') + 2000000 AS INTEGER)
      ELSE CAST (s.slice_date - TO_DATE ('01/01/2000', 'MM/DD/YYYY') + 3000000 AS INTEGER)
    END period_key,
    s.slice,
    s.created_date
  FROM prj_blb_slices s,
    cal_slice_keys sk,
    rpt_calendar c
  WHERE s.slice_request_id = sk.request_key
  AND s.slice_date         = c.start_date
  AND sk.period_type       = c.period_type
  AND s.slice             <> 0
  UNION ALL
  SELECT s.prj_object_id resource_key,
    fp.period_key,
    s.slice,
    s.created_date
  FROM prj_fiscal_blb_slices s,
    fiscal_slice_key sk,
    fiscal_periods fp
  WHERE s.slice_request_id = sk.request_key
  AND s.period_id          = fp.period_key
  AND s.slice             <> 0
    ) a;